@@ -53,11 +53,11 @@ parsers_step_1: List[ParserType] = [
 
 # Step 2 parsing, happens after getting bracketed data
 parsers_step_2: List[ParserType] = [
-    {"regex": SEASON_REGEX, "groups": {"season": "season"}},
     {
         "regex": EPISODE_SEASON_REGEX,
         "groups": {"episode": "episode", "season": "season"},
     },
+    {"regex": SEASON_REGEX, "groups": {"season": "season"}},
     {"regex": EPISODE_REGEX, "groups": {"episode": "episode"}},
     {"regex": RELEASE_GROUP_REGEX, "groups": {"release_group": "release_group"}},
 ]
@@ -170,6 +170,8 @@ def _parse_string(name: str) -> Dict[str, Any]:
     name_to_parse = re.sub(r"[\[\]]", "", name_to_parse)
     # Now remove some stuff that could be left at the end
     name_to_parse = re.sub(r" *[\-\+]+$", "", name_to_parse)
+    # And the beginning
+    name_to_parse = re.sub(r"^ *[\-\+]+ *", "", name_to_parse)
 
     # Special handling for an alternate title
     name_to_parse = ALTERNATE_TITLE_REGEX.sub(
@@ -219,15 +221,12 @@ def _parse(path: Path) -> Dict[str, Any]:
     file_data = file_data.copy()
     path_data = path_data.copy()
 
-    # Update our data with the file data
-    data.update(file_data)
-
     # Now if there is only an anime title but not an episode title, it's possible that
     # this is actually the episode title... and the anime title is in the folder name
     if "anime_title" in file_data and "episode_title" not in file_data:
         # If we have the anime title, and the alternate title... then it's likely that this is
         # just correct as is and we don't want to do anything extra
-        if "alternate_title" not in data:
+        if "alternate_title" not in file_data:
             # Special check to handle common folder names that might be general
             # containers that we want to ignore
             if path_data and path_data["anime_title"].lower() not in [
@@ -267,4 +266,8 @@ def _parse(path: Path) -> Dict[str, Any]:
         or data.get("extension") in subtitle_file_extensions
     )
 
+    # Now just to make sure the alternate title and main title aren't the same
+    if data.get("alternate_title") == data["anime_title"]:
+        data.pop("alternate_title", None)
+
     return data
